==> inkscape_0.38.1.orig.tar.gz: inkscape-0.38.1/src/helper/sp-marshal.h <==

#ifndef __sp_marshal_MARSHAL_H__
#define __sp_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* NONE:NONE (./sp-marshal.list:2) */
#define sp_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID
#define sp_marshal_NONE__NONE	sp_marshal_VOID__VOID

/* NONE:UINT (./sp-marshal.list:3) */
#define sp_marshal_VOID__UINT	g_cclosure_marshal_VOID__UINT
#define sp_marshal_NONE__UINT	sp_marshal_VOID__UINT

/* NONE:POINTER (./sp-marshal.list:4) */
#define sp_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER
#define sp_marshal_NONE__POINTER	sp_marshal_VOID__POINTER

/* NONE:POINTER,BOOLEAN (./sp-marshal.list:5) */
extern void sp_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
#define sp_marshal_NONE__POINTER_BOOLEAN	sp_marshal_VOID__POINTER_BOOLEAN

/* NONE:POINTER,UINT (./sp-marshal.list:6) */
extern void sp_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
#define sp_marshal_NONE__POINTER_UINT	sp_marshal_VOID__POINTER_UINT

/* NONE:POINTER,DOUBLE (./sp-marshal.list:7) */
extern void sp_marshal_VOID__POINTER_DOUBLE (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
#define sp_marshal_NONE__POINTER_DOUBLE	sp_marshal_VOID__POINTER_DOUBLE

/* NONE:DOUBLE,DOUBLE (./sp-marshal.list:8) */
extern void sp_marshal_VOID__DOUBLE_DOUBLE (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
#define sp_marshal_NONE__DOUBLE_DOUBLE	sp_marshal_VOID__DOUBLE_DOUBLE

/* NONE:STRING,BOOL (./sp-marshal.list:9) */
extern void sp_marshal_VOID__STRING_BOOLEAN (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
#define sp_marshal_NONE__STRING_BOOL	sp_marshal_VOID__STRING_BOOLEAN

/* BOOLEAN:NONE (./sp-marshal.list:10) */
extern void sp_marshal_BOOLEAN__VOID (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);
#define sp_marshal_BOOLEAN__NONE	sp_marshal_BOOLEAN__VOID

/* BOOLEAN:UINT (./sp-marshal.list:11) */
extern void sp_marshal_BOOLEAN__UINT (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);

/* BOOLEAN:POINTER (./sp-marshal.list:12) */
extern void sp_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
                                         const GValue *param_values,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);

/* BOOLEAN:POINTER,UINT (./sp-marshal.list:13) */
extern void sp_marshal_BOOLEAN__POINTER_UINT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* BOOLEAN:POINTER,POINTER (./sp-marshal.list:14) */
extern void sp_marshal_BOOLEAN__POINTER_POINTER (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* INT:POINTER,POINTER (./sp-marshal.list:15) */
extern void sp_marshal_INT__POINTER_POINTER (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* DOUBLE:POINTER,UINT (./sp-marshal.list:16) */
extern void sp_marshal_DOUBLE__POINTER_UINT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

G_END_DECLS

#endif /* __sp_marshal_MARSHAL_H__ */

==> inkscape_0.44.orig.tar.gz: inkscape-0.44/src/helper/sp-marshal.h <==

#ifndef __sp_marshal_MARSHAL_H__
#define __sp_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* NONE:NONE (./helper/sp-marshal.list:2) */
#define sp_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID
#define sp_marshal_NONE__NONE	sp_marshal_VOID__VOID

/* NONE:UINT (./helper/sp-marshal.list:3) */
#define sp_marshal_VOID__UINT	g_cclosure_marshal_VOID__UINT
#define sp_marshal_NONE__UINT	sp_marshal_VOID__UINT

/* NONE:POINTER (./helper/sp-marshal.list:4) */
#define sp_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER
#define sp_marshal_NONE__POINTER	sp_marshal_VOID__POINTER

/* NONE:POINTER,BOOLEAN (./helper/sp-marshal.list:5) */
extern void sp_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
#define sp_marshal_NONE__POINTER_BOOLEAN	sp_marshal_VOID__POINTER_BOOLEAN

/* NONE:POINTER,UINT (./helper/sp-marshal.list:6) */
extern void sp_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
#define sp_marshal_NONE__POINTER_UINT	sp_marshal_VOID__POINTER_UINT

/* NONE:POINTER,DOUBLE (./helper/sp-marshal.list:7) */
extern void sp_marshal_VOID__POINTER_DOUBLE (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
#define sp_marshal_NONE__POINTER_DOUBLE	sp_marshal_VOID__POINTER_DOUBLE

/* NONE:DOUBLE,DOUBLE (./helper/sp-marshal.list:8) */
extern void sp_marshal_VOID__DOUBLE_DOUBLE (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
#define sp_marshal_NONE__DOUBLE_DOUBLE	sp_marshal_VOID__DOUBLE_DOUBLE

/* NONE:STRING,BOOL (./helper/sp-marshal.list:9) */
extern void sp_marshal_VOID__STRING_BOOLEAN (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
#define sp_marshal_NONE__STRING_BOOL	sp_marshal_VOID__STRING_BOOLEAN

/* BOOLEAN:NONE (./helper/sp-marshal.list:10) */
extern void sp_marshal_BOOLEAN__VOID (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);
#define sp_marshal_BOOLEAN__NONE	sp_marshal_BOOLEAN__VOID

/* BOOLEAN:UINT (./helper/sp-marshal.list:11) */
extern void sp_marshal_BOOLEAN__UINT (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);

/* BOOLEAN:POINTER (./helper/sp-marshal.list:12) */
extern void sp_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
                                         const GValue *param_values,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);

/* BOOLEAN:POINTER,UINT (./helper/sp-marshal.list:13) */
extern void sp_marshal_BOOLEAN__POINTER_UINT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* BOOLEAN:POINTER,POINTER (./helper/sp-marshal.list:14) */
extern void sp_marshal_BOOLEAN__POINTER_POINTER (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* INT:POINTER,POINTER (./helper/sp-marshal.list:15) */
extern void sp_marshal_INT__POINTER_POINTER (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* DOUBLE:POINTER,UINT (./helper/sp-marshal.list:16) */
extern void sp_marshal_DOUBLE__POINTER_UINT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

G_END_DECLS

#endif /* __sp_marshal_MARSHAL_H__ */
